@@ -119,7 +119,7 @@ class TestMechanizeHttpContentDispositionParser < Mechanize::TestCase
 
     assert_equal 'end "', string
   end
-  
+
   def test_parse_uppercase
     content_disposition = @parser.parse \
       'content-disposition: attachment; Filename=value', true
@@ -128,5 +128,12 @@ class TestMechanizeHttpContentDispositionParser < Mechanize::TestCase
     assert_equal 'value',      content_disposition.filename
   end
 
+  def test_parse_filename_starting_with_escaped_quote
+    content_disposition = @parser.parse \
+      'content-disposition: attachment; Filename="\"value\""', true
+
+    assert_equal '"value"', content_disposition.filename
+  end
+
 end
 
